* Module:   INPUT420.PRG
* Version:      Beta 1.0
* Purpose:      Enter vegetation data in database file vegetat.dbf

* Called by:    INPUT400.PRG
* Calling:      procedure i_lukey in INPUT420.PRG

* Date:         3 May 1993
* Author:       P. Tempel
* Updates:      3 May 1993         by P. Tempel
* * * * * * * * * * * * * * *

DO WHILE .T.

   * Declaration of (temporary) vegetation cover variables
   STORE 0 TO tmp_suid, tmp_prop
   STORE SPACE(5) TO tmp_vege
   STORE SPACE(6) TO tmp_date


   * Enter a valid primary key
   DO i_vgkey
   DO CASE
      CASE tmp_suid = 0 
         EXIT
      CASE LTRIM(TRIM(tmp_date)) = ""   
         EXIT
      CASE LTRIM(TRIM(tmp_vege)) = ""
         EXIT
   ENDCASE


   * Activate semi-full screen window
   ACTIVATE WINDOW f_screen


   DO WHILE .T.

      SET BORDER TO SINGLE
      STORE .Y. TO tmp_answ
      SET FORMAT TO input420
      READ

      * Process ESC
      IF READKEY() = 12               && ESC:
         STORE .N. TO tmp_answ        && RETURN TO CALLING PROGRAM
         EXIT                         && WITHOUT SAVE
      ENDIF

      * Process input form
      IF READKEY() = 15 .OR. READKEY() = 271     && <ENTER>
         SET FORMAT TO
         CLEAR GETS
         SET CONFIRM OFF
         SET ESCAPE OFF
         @ 20, 01 CLEAR TO 20, 75
         @ 20, 01 SAY "Store to database [Y/N]?  :" GET tmp_answ PICTURE "Y"
         READ
         IF tmp_answ
            @ 20, 40 SAY "Storing data....."
            USE vegetat ORDER pk
            APPEND BLANK
            REPLACE suid WITH tmp_suid
            REPLACE date WITH tmp_date
            REPLACE vege WITH tmp_vege
            REPLACE prop WITH tmp_prop
            USE
         ENDIF
         @ 20, 01 CLEAR TO 20, 75
         CLEAR GETS
         STORE .Y. TO tmp_answ
         @ 20, 01 SAY "Insert another record [Y/N]? : " GET tmp_answ PICTURE "Y"
         READ
         
         SET CONFIRM ON
         SET ESCAPE ON
         EXIT
            
      ENDIF

   ENDDO

   IF tmp_answ
      DEACTIVATE WINDOW f_screen   && INSERT ANOTHER RECORD
      LOOP                         && START AT BEGINNING OF DO WHILE LOOP
   ELSE
      EXIT                         && RETURN TO CALLING PROGRAM
   ENDIF

ENDDO
RELEASE ALL LIKE tmp*
SET BORDER TO DOUBLE
SET FORMAT TO
DEACTIVATE WINDOW f_screen
RETURN




PROCEDURE i_vgkey
****************
SET BORDER TO SINGLE
DEFINE WINDOW i_vgkey FROM 15, 21 TO 21, 73
ACTIVATE WINDOW i_vgkey
DO WHILE .T.

   STORE 0 TO tmp_suid
   STORE SPACE(5) TO tmp_vege
   STORE SPACE(6) TO tmp_date
   CLEAR

   * Enter Vegetation primary key values
   DO WHILE .T.
      @ 01, 08 SAY "1  SOTER unit ID"
      @ 01, 37 GET tmp_suid PICTURE "@Z 9999" ;
            MESSAGE "Enter a four-digit SOTER unit ID"
      @ 02, 08 SAY "2  Date of observation"
      @ 02, 34 GET tmp_date  PICTURE "@R 99/9999"  ;
            MESSAGE "Enter date of observation in MM/YYYY format"
      @ 03, 08 SAY "3  Vegetation code"
      @ 03, 36 GET tmp_vege  FUNCTION "!" PICTURE "XXXX9"  ;
            MESSAGE "Enter a vegetation code in format AAAA#"
      READ

      IF READKEY() = 15 .OR. READKEY() = 271
         EXIT
      ENDIF

   ENDDO


   * Return if one of the primary kay values is 0 (zero)
   DO CASE
      CASE tmp_suid = 0 
         DEACTIVATE WINDOW i_vgkey
         RETURN
      CASE LTRIM(TRIM(tmp_date)) = ""
         DEACTIVATE WINDOW i_vgkey
         RETURN
      CASE LTRIM(TRIM(tmp_vege)) = ""
         DEACTIVATE WINDOW i_vgkey
         RETURN
   ENDCASE


   * Check existence of the SOTER unit_ID
   USE terrain ORDER pk
   IF .NOT. SEEK(tmp_suid)    && SUID NOT FOUND
      USE
      CLEAR
      ? beep
      @ 00, 01 SAY "ERROR:" COLOR GR+/R
      @ 02, 01 SAY LTRIM(STR(tmp_suid))+" not an existing SOTER unit"
      @ 03, 01 SAY ""
      WAIT " Press any key to continue..."
      LOOP
   ELSE
      USE
   ENDIF


   * Check validity of observation date
   tmp_month = VAL(SUBSTR(tmp_date, 1, 2))
   IF tmp_month < 1 .OR. tmp_month > 12
      CLEAR
      ? beep
      @ 00, 01 SAY "ERROR:" COLOR GR+/R
      @ 01, 01 SAY SUBSTR(tmp_date, 1, 2)+   ;
                " is not a valid month. Valid months are all"
      @ 02, 01 SAY "integers in the range from 1 to 12"
      @ 03, 01 SAY ""
      WAIT " Press any key to continue..."
      LOOP
   ENDIF

   tmp_year = VAL(SUBSTR(tmp_date, 3, 4))
   IF tmp_year < 1950 .OR. tmp_year > YEAR(DATE())
      CLEAR
      ? beep
      @ 00, 01 SAY "ERROR:" COLOR GR+/R
      @ 01, 01 SAY SUBSTR(tmp_date, 3, 4)+;
                 " is not a valid year. Valid years are all"
      @ 02, 01 SAY "integers from 1950 to "+LTRIM(STR(YEAR(DATE())))
      @ 03, 01 SAY ""
      WAIT " Press any key to continue..."
      LOOP
   ENDIF


   * Check existence of vegetation code
   USE veg_code ORDER pk
   IF .NOT. SEEK(LTRIM(TRIM(tmp_vege)))   && LAND USE CODE NOT FOUND
      USE
      CLEAR
      ? beep
      @ 00, 01 SAY "ERROR:" COLOR GR+/R
      @ 02, 01 SAY LTRIM(TRIM(tmp_vege))+" not a valid vegetation code"
      @ 03, 01 SAY ""
      WAIT " Press any key to continue..."
      LOOP
   ELSE
      USE
   ENDIF


   * Check values for primary key of database file landuse.dbf
   STORE STR(tmp_suid)+LTRIM(TRIM(tmp_date))+LTRIM(TRIM(tmp_vege)) TO vg_pk
   USE vegetat ORDER pk
   IF SEEK(vg_pk)
      USE
      CLEAR
      ? beep
      @ 00, 01 SAY "ERROR:" COLOR GR+/R
      @ 01, 01 SAY "SOTER unit ID "+LTRIM(STR(tmp_suid))+;
                   ", observation date "+SUBSTR(tmp_date, 1, 2)+"/"+;
                   SUBSTR(tmp_date, 3, 4)
      @ 02, 01 SAY "and vegetation code "+LTRIM(TRIM(tmp_vege))+;
                      " do not yield a unique"
      @ 03, 01 SAY "primary key for the vegetation database file"
      WAIT " Press any key to continue..."
      LOOP
   ELSE
      USE
   ENDIF

   EXIT   && Leave DO WHILE loop after checking key vlues

ENDDO
DEACTIVATE WINDOW i_vgkey
RELEASE WINDOW i_vgkey
SET BORDER TO DOUBLE
RETURN
